@@ -1,7 +1,7 @@
 package Log::ger::App;
 
 our $DATE = '2017-07-12'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -47,8 +47,9 @@ sub import {
     require Log::ger;
     require Log::ger::Util;
 
-    my $level = Log::ger::Util::numeric_level(_level_from_env("") || 'warn');
-    $Log::ger::Current_Level = $level;
+    my $level = $args{level};
+    $level = _level_from_env("") || 'warn' if !defined($level);
+    $Log::ger::Current_Level = Log::ger::Util::numeric_level($level);
 
     my $is_daemon = $args{daemon};
     $is_daemon = _is_daemon() if !defined($is_daemon);
@@ -72,8 +73,9 @@ sub import {
     # add Screen
     unless ($is_daemon) {
         $conf{outputs}{Screen} = {
+            conf   => { formatter => sub { "$progname: $_[0]" } },
             level  => _level_from_env("SCREEN_"),
-            layout => [Pattern => {format => $is_oneliner ? '[%r] %m' : '[%d] %m'}],
+            #layout => [Pattern => {format => '%m'}],
         };
     }
 
@@ -117,7 +119,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -154,6 +156,10 @@ Arguments:
 
 =over
 
+=item * level => str|num
+
+Explicitly set level.
+
 =item * name => str
 
 Explicitly set program name. Otherwise, default will be taken from C<$0> (after
